@@ -74,6 +74,7 @@ static char  mainName[] = "dwamorph2_reg";
 
         /*  ---------  dilation  ----------*/
 
+    lept_mkdir("morph");
     for (i = 0; i < nsels / 2; i++)
     {
         sel = selaGetSel(selalinear, i);
@@ -111,7 +112,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/junkdilate", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/morph/dilate", GPLOT_PNG,
                         "Dilation time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -166,7 +167,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/junkerode", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/morph/erode", GPLOT_PNG,
                         "Erosion time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -221,7 +222,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/junkopen", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/morph/open", GPLOT_PNG,
                         "Opening time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -276,7 +277,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/junkclose", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/morph/close", GPLOT_PNG,
                         "Closing time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -307,16 +308,16 @@ static char  mainName[] = "dwamorph2_reg";
 
         /* Display the results together */
     pixa = pixaCreate(0);
-    pixs = pixRead("/tmp/junkdilate.png");
+    pixs = pixRead("/tmp/morph/dilate.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/junkerode.png");
+    pixs = pixRead("/tmp/morph/erode.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/junkopen.png");
+    pixs = pixRead("/tmp/morph/open.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/junkclose.png");
+    pixs = pixRead("/tmp/morph/close.png");
     pixaAddPix(pixa, pixs, L_INSERT);
     pixt = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 40, 3);
-    pixWrite("/tmp/junktimings.png", pixt, IFF_PNG);
+    pixWrite("/tmp/morph/timings.png", pixt, IFF_PNG);
     pixDisplay(pixt, 100, 100);
     pixDestroy(&pixt);
     pixaDestroy(&pixa);
