@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -31,15 +42,14 @@
 
 #define  DISPLAY_SEPARATION   0   /* use 250 to get images displayed */
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
-char        *infile;
 PIX         *pixs, *pixg, *pixc, *pixd;
 static char  mainName[] = "morphseq_reg";
 
     if (argc != 1)
-	return ERROR_INT(" Syntax:  morphseq_reg", mainName, 1);
+        return ERROR_INT(" Syntax:  morphseq_reg", mainName, 1);
 
     pixs = pixRead("feyn.tif");
 
@@ -56,6 +66,9 @@ static char  mainName[] = "morphseq_reg";
     pixWrite("/tmp/morphseq2.png", pixd, IFF_PNG);
     pixDestroy(&pixd);
 
+    fprintf(stderr, "\n ------------------ Error messages -----------------\n");
+    fprintf(stderr, " ------------  DWA v23 Sel doesn't exist -----------\n");
+    fprintf(stderr, " ---------------------------------------------------\n");
     pixd = pixMorphSequenceDwa(pixs, SEQUENCE2, -3);
     pixDestroy(&pixd);
     pixd = pixMorphSequenceDwa(pixs, SEQUENCE2, DISPLAY_SEPARATION);
@@ -90,7 +103,9 @@ static char  mainName[] = "morphseq_reg";
     pixDestroy(&pixd);
 
         /* Syntax error handling */
-    fprintf(stderr, " ------------ Error messages follow ------------------\n");
+    fprintf(stderr, "\n ----------------- Error messages ------------------\n");
+    fprintf(stderr, " ---------------- Invalid sequence -----------------\n");
+    fprintf(stderr, " ---------------------------------------------------\n");
     pixd = pixMorphSequence(pixs, BAD_SEQUENCE, 50);  /* fails; returns null */
     pixd = pixGrayMorphSequence(pixg, BAD_SEQUENCE, 50, 0);  /* this fails */
 
