@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -43,11 +54,11 @@ static void PixSave32(PIXA *pixa, PIX *pixc);
 static void PixaSaveDisplay(PIXA *pixa, L_REGPARAMS *rp);
 
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
 l_int32       i;
-PIX          *pixs, *pixc, *pixd;
+PIX          *pixs, *pixc;
 PIXA         *pixa;
 L_REGPARAMS  *rp;
 
@@ -60,7 +71,7 @@ L_REGPARAMS  *rp;
     pixs = pixRead(image[0]);
     pixc = pixScale(pixs, 0.32, 0.32);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);
-    pixSaveTiled(pixc, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixc, pixa, 1.0, 1, SPACE, 32);
     pixDestroy(&pixc);
 
     pixc = pixScaleToGray3(pixs);
@@ -69,7 +80,7 @@ L_REGPARAMS  *rp;
 
     pixc = pixScaleToGray4(pixs);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);
-    pixSaveTiled(pixc, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixc, pixa, 1.0, 1, SPACE, 32);
     pixDestroy(&pixc);
 
     pixc = pixScaleToGray6(pixs);
@@ -96,7 +107,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 2 bpp without cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[1]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 2.25, 2.25);
     regTestWritePixAndCheck(rp, pixc, IFF_JFIF_JPEG);
     PixSave32(pixa, pixc);
@@ -113,7 +124,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 2 bpp with cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[2]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 2.25, 2.25);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);
     PixSave32(pixa, pixc);
@@ -130,7 +141,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 4 bpp without cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[3]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.72, 1.72);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);
     PixSave32(pixa, pixc);
@@ -147,7 +158,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 4 bpp with cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[4]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.72, 1.72);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);
     PixSave32(pixa, pixc);
@@ -164,7 +175,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 8 bpp without cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[5]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.92, 1.92);
     regTestWritePixAndCheck(rp, pixc, IFF_JFIF_JPEG);
     PixSave32(pixa, pixc);
@@ -181,7 +192,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 8 bpp with cmap ----------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[6]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.92, 1.92);
     regTestWritePixAndCheck(rp, pixc, IFF_JFIF_JPEG);
     PixSave32(pixa, pixc);
@@ -198,7 +209,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 16 bpp ------------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[7]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.92, 1.92);
     regTestWritePixAndCheck(rp, pixc, IFF_JFIF_JPEG);
     PixSave32(pixa, pixc);
@@ -215,7 +226,7 @@ L_REGPARAMS  *rp;
     fprintf(stderr, "\n-------------- Testing 32 bpp ------------\n");
     pixa = pixaCreate(0);
     pixs = pixRead(image[8]);
-    pixSaveTiled(pixs, pixa, 1, 1, SPACE, 32);
+    pixSaveTiled(pixs, pixa, 1.0, 1, SPACE, 32);
     pixc = pixScale(pixs, 1.42, 1.42);
     regTestWritePixAndCheck(rp, pixc, IFF_JFIF_JPEG);
     PixSave32(pixa, pixc);
@@ -248,9 +259,9 @@ PIX       *pixs, *pixt1, *pixt2, *pix32;
         pixt2 = pixScale(pixt1, scalefactor, scalefactor);
         pix32 = pixConvertTo32(pixt2);
         if (i == 0)
-            pixSaveTiled(pix32, pixa, 1, 1, SPACE, 32);
+            pixSaveTiled(pix32, pixa, 1.0, 1, SPACE, 32);
         else
-            pixSaveTiled(pix32, pixa, 1, 0, SPACE, 32);
+            pixSaveTiled(pix32, pixa, 1.0, 0, SPACE, 32);
         pixDestroy(&pixt1);
         pixDestroy(&pixt2);
         pixDestroy(&pix32);
@@ -264,7 +275,7 @@ PixSave32(PIXA *pixa, PIX *pixc)
 {
 PIX  *pix32;
     pix32 = pixConvertTo32(pixc);
-    pixSaveTiled(pix32, pixa, 1, 0, SPACE, 32);
+    pixSaveTiled(pix32, pixa, 1.0, 0, SPACE, 32);
     pixDestroy(&pixc);
     pixDestroy(&pix32);
     return;
